package com.miaxis.jsgzh.domain;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.miaxis.common.annotation.Excel;
import com.miaxis.common.core.domain.BaseBusinessEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
/**
 * 极速公众号用户对象 jsgzh_user
 *
 * @author miaxis
 * @date 2021-06-08
 */
@Data
@ApiModel(value = "JsgzhUser", description = "极速公众号用户对象 jsgzh_user")
@TableName(value = "jsgzh_user")
public class JsgzhUser extends BaseBusinessEntity  implements Serializable {
    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id")
    @ApiModelProperty(value = "主键")
    private Long id;

    /** 公众号openid */
    @Excel(name = "公众号openid")
    @TableField("openid")
    @ApiModelProperty(value = "公众号openid")
    private String openid;

    /** 用户的昵称 */
    @Excel(name = "用户的昵称")
    @TableField("nickname")
    @ApiModelProperty(value = "用户的昵称")
    private String nickname;

    /** 1关注 0未关注 用户是否订阅该公众号标识，值为0时，代表此用户没有关注该公众号，拉取不到其余信息。 */
    @Excel(name = "1关注 0未关注 用户是否订阅该公众号标识，值为0时，代表此用户没有关注该公众号，拉取不到其余信息。")
    @TableField("subscribe")
    @ApiModelProperty(value = "1关注 0未关注 用户是否订阅该公众号标识，值为0时，代表此用户没有关注该公众号，拉取不到其余信息。")
    private Long subscribe;

    /** 用户的性别，值为1时是男性，值为2时是女性，值为0时是未知 */
    @Excel(name = "用户的性别，值为1时是男性，值为2时是女性，值为0时是未知")
    @TableField("sex")
    @ApiModelProperty(value = "用户的性别，值为1时是男性，值为2时是女性，值为0时是未知")
    private Long sex;

    /** 用户所在城市 */
    @Excel(name = "用户所在城市")
    @TableField("city")
    @ApiModelProperty(value = "用户所在城市")
    private String city;

    /** 用户所在国家 */
    @Excel(name = "用户所在国家")
    @TableField("country")
    @ApiModelProperty(value = "用户所在国家")
    private String country;

    /** 用户所在省份
用户所在省份 */
    @Excel(name = "用户所在省份 用户所在省份")
    @TableField("province")
    @ApiModelProperty(value = "用户所在省份 用户所在省份")
    private String province;

    /** 用户的语言，简体中文为zh_CN */
    @Excel(name = "用户的语言，简体中文为zh_CN")
    @TableField("language")
    @ApiModelProperty(value = "用户的语言，简体中文为zh_CN")
    private String language;

    /** 用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空。若用户更换头像，原有头像URL将失效。 */
    @Excel(name = "用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空。若用户更换头像，原有头像URL将失效。", readConverterExp = "有=0、46、64、96、132数值可选，0代表640*640正方形头像")
    @TableField("headimgurl")
    @ApiModelProperty(value = "用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空。若用户更换头像，原有头像URL将失效。")
    private String headimgurl;

    /** 用户关注时间，为时间戳。如果用户曾多次关注，则取最后关注时间 */
    @TableField("subscribe_time")
    @ApiModelProperty(value = "用户关注时间，为时间戳。如果用户曾多次关注，则取最后关注时间")
    private Date subscribe_time;

    /** 只有在用户将公众号绑定到微信开放平台帐号后，才会出现该字段。 */
    @Excel(name = "只有在用户将公众号绑定到微信开放平台帐号后，才会出现该字段。")
    @TableField("unionid")
    @ApiModelProperty(value = "只有在用户将公众号绑定到微信开放平台帐号后，才会出现该字段。")
    private String unionid;

    /** 用户所在的分组ID（兼容旧的用户分组接口） */
    @Excel(name = "用户所在的分组ID（兼容旧的用户分组接口）", readConverterExp = "兼=容旧的用户分组接口")
    @TableField("groupid")
    @ApiModelProperty(value = "用户所在的分组ID（兼容旧的用户分组接口）")
    private Long groupid;

    /** 用户被打上的标签ID列表
 */
    @Excel(name = "用户被打上的标签ID列表 ")
    @ApiModelProperty(value = "用户被打上的标签ID列表")
    @TableField(value="tagid_list",typeHandler = JacksonTypeHandler.class)
    private JSONArray tagid_list;

    /** 返回用户关注的渠道来源，ADD_SCENE_SEARCH 公众号搜索，ADD_SCENE_ACCOUNT_MIGRATION 公众号迁移，ADD_SCENE_PROFILE_CARD 名片分享，ADD_SCENE_QR_CODE 扫描二维码，ADD_SCENE_PROFILE_LINK 图文页内名称点击，ADD_SCENE_PROFILE_ITEM 图文页右上角菜单，ADD_SCENE_PAID 支付后关注，ADD_SCENE_WECHAT_ADVERTISEMENT 微信广告，ADD_SCENE_OTHERS 其他 */
    @Excel(name = "返回用户关注的渠道来源，ADD_SCENE_SEARCH 公众号搜索，ADD_SCENE_ACCOUNT_MIGRATION 公众号迁移，ADD_SCENE_PROFILE_CARD 名片分享，ADD_SCENE_QR_CODE 扫描二维码，ADD_SCENE_PROFILE_LINK 图文页内名称点击，ADD_SCENE_PROFILE_ITEM 图文页右上角菜单，ADD_SCENE_PAID 支付后关注，ADD_SCENE_WECHAT_ADVERTISEMENT 微信广告，ADD_SCENE_OTHERS 其他")
    @TableField("subscribe_scene")
    @ApiModelProperty(value = "ROFILE_LINK 图文页内名称点击，ADD_SCENE_PROFILE_ITEM 图文页右上角菜单，ADD_SCENE_PAID 支付后关注，ADD_SCENE_WECHAT_ADVERTISEMENT 微信广告，ADD_SCENE_OTHERS 其他")
    private String subscribe_scene;


    /** 创建时间 */
    @TableField("create_time")
    @ApiModelProperty(value = "创建时间")
    private Date create_time;

    /** 创建时间 */
    @TableField("update_time")
    @ApiModelProperty(value = "创建时间")
    private Date update_time;


    /** 是否已经获取个人信息 */
    @TableField("is_get")
    @ApiModelProperty(value = "是否已经获取个人信息")
    private Long is_get;
}
